summaryrefslogtreecommitdiff
path: root/apps/netutils/ftpc/ftpc_idle.c
diff options
context:
space:
mode:
Diffstat (limited to 'apps/netutils/ftpc/ftpc_idle.c')
-rw-r--r--apps/netutils/ftpc/ftpc_idle.c7
1 files changed, 4 insertions, 3 deletions
diff --git a/apps/netutils/ftpc/ftpc_idle.c b/apps/netutils/ftpc/ftpc_idle.c
index 2d049f8b4..95a94d233 100644
--- a/apps/netutils/ftpc/ftpc_idle.c
+++ b/apps/netutils/ftpc/ftpc_idle.c
@@ -91,7 +91,7 @@ int ftpc_idle(SESSION handle, unsigned int idletime)
if (!FTPC_HAS_IDLE(session))
{
- ndbg("Server doesn't support SITE IDLE\n");
+ ndbg("Server does not support SITE IDLE\n");
return ERROR;
}
@@ -108,12 +108,13 @@ int ftpc_idle(SESSION handle, unsigned int idletime)
ret = ftpc_cmd(session, "SITE IDLE");
}
- /* Check for "502 Command not implemented" */
+ /* Check for "502 Command not implemented" or 500 "Unknown SITE command" */
- if (session->code == 502)
+ if (session->code == 500 || session->code == 502)
{
/* Server does not support SITE IDLE */
+ ndbg("Server does not support SITE IDLE\n");
FTPC_CLR_IDLE(session);
}